@@ -3,9 +3,9 @@ package Sah::Schema::percent;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-09-22'; # DATE
+our $DATE = '2022-10-20'; # DATE
 our $DIST = 'Sah-Schemas-Float'; # DIST
-our $VERSION = '0.012'; # VERSION
+our $VERSION = '0.013'; # VERSION
 
 our $schema = ['float', {
     summary => 'A float',
@@ -31,7 +31,7 @@ _
         {value=>5, valid=>1, validated_value=>0.05},
         {value=>'5%', valid=>1, validated_value=>0.05},
     ],
-}, {}];
+}];
 
 1;
 # ABSTRACT: A float
@@ -48,7 +48,7 @@ Sah::Schema::percent - A float
 
 =head1 VERSION
 
-This document describes version 0.012 of Sah::Schema::percent (from Perl distribution Sah-Schemas-Float), released on 2022-09-22.
+This document describes version 0.013 of Sah::Schema::percent (from Perl distribution Sah-Schemas-Float), released on 2022-10-20.
 
 =head1 SYNOPSIS
 
@@ -78,7 +78,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = 0.5;
+ $data = "5%";
  my $errmsg = $validator->($data); # => ""
 
 Often a schema has coercion rule or default value, so after validation the
@@ -89,8 +89,8 @@ prefiltered) value:
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = 0.5;
- my $res = $validator->($data); # => ["",0.005]
+ $data = "5%";
+ my $res = $validator->($data); # => ["",0.05]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
@@ -153,6 +153,23 @@ L<Perinci::CmdLine> (L<Perinci::CmdLine::Lite>) to create a CLI:
 
  % ./myapp.pl --arg1 ...
 
+
+=head2 Using with Type::Tiny
+
+To create a type constraint and type library from a schema:
+
+ package My::Types {
+     use Type::Library -base;
+     use Type::FromSah qw( sah2type );
+
+     __PACKAGE__->add_type(
+         sah2type('$sch_name*', name=>'Percent')
+     );
+ }
+
+ use My::Types qw(Percent);
+ Percent->assert_valid($data);
+
 =head1 DESCRIPTION
 
 This type is basically C<float>, with C<str_as_percent> coerce rule. So the
